@@ -32,8 +32,8 @@ import utils.list_utils as _lu
 import utils.string_utils as _csu
 import utils.file_utils as _f
 import utils.sql_utils as _sql
-import config as _config
-_log = _config.log
+import utils.console_utils as _console
+_log = _console.log
 
 _sql_data_types = [
     "mediumtext",
@@ -97,6 +97,61 @@ _sql_types_with_sizes = [
     "bit",
 ]
 
+
+def is_valid_mysql_data_type(value:str):
+    data = mysql_parse_type_data(value)
+    if data is False or data['type'] is None:
+        return False
+    value = data['type']
+
+    if value in _sql_data_types:
+        return data
+
+    value_lower = value.lower()
+    if value_lower in _sql_data_types:
+        data['type'] = value_lower
+        return data
+
+    varis = _csu.variations(value)
+    for var in varis:
+        if var in _sql_data_types:
+            data["type"] = var
+            return data
+    return False
+
+def mysql_parse_type_data(value:str):
+    if isinstance(value,(str)) is False:
+        return False
+    value = value.lower()
+    data = {
+        "type":None,
+        "size":None,
+    }
+    
+    pat = _re.compile(r"([A-Za-z]*)(?:\(([0-9]*)\))?")
+    match = _re.findall(pat,value)
+    if match is not None:
+        if len(match) > 0:
+            type_name = match[0][0]
+            type_size = match[0][1]
+            # print(f"match[0]:{match[0]}")
+            # print(f"    type_name:{type_name}")
+            data['type'] = type_name
+            if len(type_size) > 0:
+                data['size'] = int(type_size)
+                
+    return data
+
+def gen_mysql_type(name:str,size:int=None):
+    name = name.lower()
+    if size is not None:
+        if name in _sql_types_with_sizes:
+            return f"{name}({size})"
+    if size is None:
+        if name in _sql_data_types:
+            return f"{name}"
+
+
 def sql_type_to_python(value):
     '''
         Attempts to convert an sql type to its python equivalent.
@@ -985,44 +1040,6 @@ def parse_col_type(col_data):
         @xxx [05-31-2022 07:54:59]: documentation for parse_col_type
     '''
 
-
-    # _sql_data_types = [
-    #     "mediumtext",
-    #     "mediumblob",
-    #     "varbinary",
-    #     "timestamp",
-    #     "mediumint",
-    #     "tinytext",
-    #     "tinyblob",
-    #     "smallint",
-    #     "longtext",
-    #     "longblob",
-    #     "datetime",
-    #     "varchar",
-    #     "tinyint",
-    #     "integer",
-    #     "decimal",
-    #     "boolean",
-    #     "double",
-    #     "double",
-    #     "binary",
-    #     "bigint",
-    #     "float",
-    #     "float",
-    #     "year",
-    #     "time",
-    #     "text",
-    #     "enum",
-    #     "date",
-    #     "char",
-    #     "bool",
-    #     "blob",
-    #     "set",
-    #     "int",
-    #     "dec",
-    #     "bit",
-    # ]
-
     for t in col_data['shlexed']:
         for sql_type in _sql_data_types:
             if sql_type in t.lower():
@@ -1066,33 +1083,8 @@ def parse_column_size(type_string):
     '''
 
 
-    sized_cols = [
-        "varbinary",
-        "mediumint",
-        "timestamp",
-        "smallint",
-        "datetime",
-        "varchar",
-        "decimal",
-        "integer",
-        "tinyint",
-        "binary",
-        "double",
-        "double",
-        "bigint",
-        "float",
-        "float",
-        "text",
-        "char",
-        "time",
-        "blob"
-        "dec",
-        "int",
-        "bit",
-    ]
-
     lower_raw = type_string.lower()
-    for sc in sized_cols:
+    for sc in _sql_types_with_sizes:
         if sc in lower_raw:
             pat = _re.compile(sc+r"\(([0-9]*)\)")
             match = _re.findall(pat,lower_raw)
